==> scan-while-right-2.9.42.tgz: package/README.md <==
Scans from right, while a test passes. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [scanWhile], [scanWhileRight], [scanUntil], [scanUntilRight].<br>
> Similar: [search], [scan], [find].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
iterable.scanWhileRight(x, ft);
// x:  an iterable
// ft: test function (v, i, x)
// --> first index where test passes till end
```

```javascript
const iterable = require('extra-iterable');

var x = [1, 1, 2, 2, 3, 3, 4, 4];
iterable.scanWhileRight(x, v => v % 3 !== 0);
// 6                       ^

iterable.scanWhileRight(x, v => v % 2 !== 0);
// 8                            ^

iterable.scanWhileRight(x, v => v % 6 !== 0);
// 0    ^
```

### references

- [List-Extra.elemIndex: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndex)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[search]: https://github.com/nodef/extra-iterable/wiki/search
[searchRight]: https://github.com/nodef/extra-iterable/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-iterable/wiki/searchAll
[:running:]: https://npm.runkit.com/@extra-iterable/scan-while-right
[:package:]: https://www.npmjs.com/package/@extra-iterable/scan-while-right
[:moon:]: https://www.npmjs.com/package/@extra-iterable/scan-while-right.min
[:ledger:]: https://unpkg.com/@extra-iterable/scan-while-right/
[scanWhile]: https://github.com/nodef/extra-iterable/wiki/scanWhile
[scanWhileRight]: https://github.com/nodef/extra-iterable/wiki/scanWhileRight
[scanUntil]: https://github.com/nodef/extra-iterable/wiki/scanUntil
[scanUntilRight]: https://github.com/nodef/extra-iterable/wiki/scanUntilRight
[scan]: https://github.com/nodef/extra-iterable/wiki/scan
[find]: https://github.com/nodef/extra-iterable/wiki/find
[:vhs:]: https://asciinema.org/a/339812

==> scan-while-right-2.9.45.tgz: package/README.md <==
Scans from right, while a test passes. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [scanWhile], [scanWhileRight], [scanUntil], [scanUntilRight].<br>
> Similar: [search], [scan], [find].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.scanWhileRight(x, ft);
// x:  an array
// ft: test function (v, i, x)
// --> first index where test passes till end
```

```javascript
const iterable = require('extra-iterable');

var x = [1, 1, 2, 2, 3, 3, 4, 4];
iterable.scanWhileRight(x, v => v % 3 !== 0);
// 6                       ^

iterable.scanWhileRight(x, v => v % 2 !== 0);
// 8                            ^

iterable.scanWhileRight(x, v => v % 6 !== 0);
// 0    ^
```

### references

- [List-Extra.elemIndex: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndex)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[search]: https://github.com/nodef/extra-iterable/wiki/search
[searchRight]: https://github.com/nodef/extra-iterable/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-iterable/wiki/searchAll
[:running:]: https://npm.runkit.com/@extra-iterable/scan-while-right
[:package:]: https://www.npmjs.com/package/@extra-iterable/scan-while-right
[:moon:]: https://www.npmjs.com/package/@extra-iterable/scan-while-right.min
[:ledger:]: https://unpkg.com/@extra-iterable/scan-while-right/
[scanWhile]: https://github.com/nodef/extra-iterable/wiki/scanWhile
[scanWhileRight]: https://github.com/nodef/extra-iterable/wiki/scanWhileRight
[scanUntil]: https://github.com/nodef/extra-iterable/wiki/scanUntil
[scanUntilRight]: https://github.com/nodef/extra-iterable/wiki/scanUntilRight
[scan]: https://github.com/nodef/extra-iterable/wiki/scan
[find]: https://github.com/nodef/extra-iterable/wiki/find
[:vhs:]: https://asciinema.org/a/339812
[:running:]: https://npm.runkit.com/@extra-array/scan-while-right
[:package:]: https://www.npmjs.com/package/@extra-array/scan-while-right
[:moon:]: https://www.npmjs.com/package/@extra-array/scan-while-right.min
[:ledger:]: https://unpkg.com/@extra-array/scan-while-right/
